<?php
/**
 * Add product's to cart based on plugin type.
 *
 * @param array $product_ids_array all product id.
 * @param array $course_id current course id.
 */
function ldfbt_process_add_to_cart( $product_ids_array, $course_id ) {
	$current_post_id   = isset( $_POST['postId'] ) ? intval( wp_unslash( $_POST['postId'] ) ) : 0;
	$current_post_type = get_post_type( $current_post_id ); // current page post type.

	$wc_cart_product_ids  = array(); // stores wc cart product ids.
	$edd_cart_product_ids = array(); // stored edd cart product ids.

	if ( 'product' === $current_post_type || 'woocom' === ldfbt_check_option_status() ) {

		// stores product ids that are already in cart.
		foreach ( WC()->cart->get_cart() as $cart_item ) {
			$wc_cart_product_ids[] = intval( $cart_item['product_id'] );
		}

		// Add woocommerce products to cart on cheking with already exist product in cart with custom metavalue.
		foreach ( $product_ids_array as $pid ) {
			if ( ! in_array( $pid, $wc_cart_product_ids, true ) ) {
				WC()->cart->add_to_cart( $pid, 1, 0, array(), array() );
			}
		}
		$wc_cart_url = wc_get_cart_url(); // gets woocommerce cart page url.
		echo wp_json_encode( array( 'woocom' => $wc_cart_url ) );
	} elseif ( 'download' === $current_post_type || 'edd' === ldfbt_check_option_status() ) {
		$cart_contents = edd_get_cart_contents(); // get edd cart content.

		// stores all product of edd cart.
		if ( ! empty( $cart_contents ) ) {
			foreach ( $cart_contents as $item ) {
				array_push( $edd_cart_product_ids, intval( $item['id'] ) );
			}
		}

		// Add EDD products to cart on cheking with existing product in cart with custom metavalue.
		foreach ( $product_ids_array as $pid ) {
			if ( ! in_array( $pid, $edd_cart_product_ids, true ) ) {
				EDD()->cart->add( $pid );
			}
		}
		$edd_cart_url = edd_get_checkout_uri(); // gets edd cart page url.
		echo wp_json_encode( array( 'edd' => $edd_cart_url ) );
	}
}

/**
 * Add fbt produts to cart.
 */
function ldfbt_ajax_add_free_cart() {
	global $wpdb;

	// current page post id and type.
	$current_post_id   = isset( $_POST['postId'] ) ? intval( wp_unslash( $_POST['postId'] ) ) : 0;
	$current_post_type = get_post_type( $current_post_id );

	if ( 'sfwd-courses' === $current_post_type ) {

		$product_ids_array    = array(); // stores product ids.
		$frequent_course_data = array(); // all fbt course id.

		$fbt_selected_courses = ldfbt_get_courses( $current_post_id ); // gets selected course data.

		if ( $fbt_selected_courses ) {
			if ( $fbt_selected_courses['selected_course'] ) {
				$frequent_course_data = $fbt_selected_courses['selected_course'];
			}
		}

		// gets final fbt course by adding current course.
		$fbt_wiget_course_ids = ldfbt_get_fbt_widget_courses( $frequent_course_data, $current_post_id );

		// if user logined check with enrolled courses.
		if ( is_user_logged_in() ) {
			$valid_course_ids = array_diff( $fbt_wiget_course_ids, learndash_user_get_enrolled_courses( get_current_user_id() ) );
		} else {
			$valid_course_ids = $fbt_wiget_course_ids;
		}

		// based on plugin type select convert course id into product ids.
		if ( 'woocom' === ldfbt_check_option_status() ) {

			// store product id by getting from course id.
			foreach ( $valid_course_ids as $ids ) {
				$wc_product_id       = $wpdb->get_var( "SELECT post_id FROM $wpdb->postmeta WHERE `meta_key` LIKE '_related_course' AND `meta_value` LIKE '%" . intval( $ids ) . "%' ORDER BY `post_id` ASC" );
				$product_ids_array[] = intval( $wc_product_id );
			}
			ldfbt_process_add_to_cart( $product_ids_array, $current_post_id );
		} elseif ( 'edd' === ldfbt_check_option_status() ) {

			// store product id by getting from course id.
			foreach ( $valid_course_ids as $ids ) {
				$edd_product_id      = $wpdb->get_var( "SELECT post_id FROM $wpdb->postmeta WHERE `meta_key` LIKE '_edd_learndash_course' AND `meta_value` LIKE '%" . intval( $ids ) . "%' ORDER BY `post_id` ASC" );
				$product_ids_array[] = intval( $edd_product_id );
			}
			ldfbt_process_add_to_cart( $product_ids_array, $current_post_id );
		}
	}
	die();
}
add_action( 'wp_ajax_ldfbt_free_cart', 'ldfbt_ajax_add_free_cart' );
add_action( 'wp_ajax_nopriv_ldfbt_free_cart', 'ldfbt_ajax_add_free_cart' );
