<?php
/**
 * Gets product id and return valid course.
 *
 * @param array $data course id data.
 * @param int   $course_id course id data.
 * @return array
 */
function ldfbt_get_course_id( $data = array(), $course_id = 0 ) {
	$valid_courses = array(); // all valid course id.
	$plugin_type   = ldfbt_check_option_status(); // selected plugin to work with.

	$wc_installed  = ldfbt_is_woocom_active() && ldfbt_is_woocom_ld_active() ? 1 : 0;
	$edd_installed = ldfbt_is_edd_active() && ldfbt_is_edd_ld_active() ? 1 : 0;

	foreach ( $data as $id ) {

		if ( 'woocom' === $plugin_type && ( $wc_installed ) ) {

			$wc_linked_course_id = metadata_exists( 'post', $id, '_related_course' ) ? get_post_meta( $id, '_related_course', true ) : null;
			if ( ! empty( $wc_linked_course_id ) ) {

				$conv_course_id = array_shift( $wc_linked_course_id );
				if ( 'publish' === get_post_status( $conv_course_id ) ) {
					if ( intval( $conv_course_id ) !== intval( $course_id ) ) {
						array_push( $valid_courses, intval( $conv_course_id ) );
					}
				}
			}
		} elseif ( 'edd' === $plugin_type && ( $edd_installed ) ) {

			$edd_linked_course_id = metadata_exists( 'post', $id, '_edd_learndash_course' ) ? get_post_meta( $id, '_edd_learndash_course', true ) : null;
			if ( ! empty( $edd_linked_course_id ) ) {

				$conv_course_id = array_shift( $edd_linked_course_id );
				if ( 'publish' === get_post_status( $conv_course_id ) ) {
					if ( intval( $conv_course_id ) !== intval( $course_id ) ) {
						array_push( $valid_courses, intval( $conv_course_id ) );
					}
				}
			}
		}
	}
	return $valid_courses;
}

/**
 * Gets the unique course ids with current course.
 *
 * @param array $course_ids .
 * @param int   $course_id .
 * @return array
 */
function ldfbt_get_fbt_widget_courses( $course_ids, $course_id ) {
	$page_course_ids = array();
	array_push( $page_course_ids, $course_id ); // add current page course id to array.

	// merge array of current course id and all selected course ids.
	$fbt_widget_course_ids = array_merge( $course_ids, $page_course_ids );

	// if array contain only one course.
	if ( count( $fbt_widget_course_ids ) < 2 ) {

		// if found only current course ten return empty array.
		if ( in_array( $course_id, $fbt_widget_course_ids, true ) ) {
			return array();
		}
	} else {
		return $fbt_widget_course_ids;
	}
}
