<?php
/**
 * Create frequent bought together course metabox on course page.
 *
 * @param object $post .
 */
function ldfbt_frequent_course_metabox_callback( $post ) {
	global $wpdb;
	$current_course_id = $post->ID; // course id of current course.
	$plugin_type       = ldfbt_check_option_status(); // selected plugin to work with.

	// edd & woocommerce install status.
	$wc_installed  = ldfbt_is_woocom_active() && ldfbt_is_woocom_ld_active() ? 1 : 0;
	$edd_installed = ldfbt_is_edd_active() && ldfbt_is_edd_ld_active() ? 1 : 0;

	$related_course_ids  = array(); // all course ids to show in upsell metabox.
	$selected_course_ids = array(); // all selected course ids from metabox.

	// gets product ids from edd or wooCommerce depend on plugin selected.
	if ( 'woocom' === $plugin_type && ( $wc_installed ) ) {
		$product_ids = $wpdb->get_col( $wpdb->prepare( "SELECT ID FROM $wpdb->posts WHERE post_type = %s AND post_status = %s", 'product', 'publish' ) );
	} elseif ( 'edd' === $plugin_type && ( $edd_installed ) ) {
		$product_ids = $wpdb->get_col( $wpdb->prepare( "SELECT ID FROM $wpdb->posts WHERE post_type = %s AND post_status = %s", 'download', 'publish' ) );
	} else {
		$product_ids = array();
	}

	// gets course id's after converting from product id.
	if ( ! empty( $product_ids ) ) {

		// all converted course id from product id.
		if ( ! empty( ldfbt_get_course_id( $product_ids, $current_course_id ) ) ) {
			array_push( $related_course_ids, ldfbt_get_course_id( $product_ids, $current_course_id ) );
		}
		if ( isset( $related_course_ids[0] ) ) {
			$related_course_ids = array_shift( $related_course_ids );
		}
	}

	// gets selected course id from metabox.
	if ( metadata_exists( 'post', $current_course_id, 'ldfbt-frequent-course' ) ) {
		$selected_course_array = get_post_meta( $current_course_id, 'ldfbt-frequent-course', true );
	} else {
		$selected_course_array = array();
	}

	// stores selected course id by checking if that course is linked to any course in wocoom or edd.
	if ( ! empty( $selected_course_array ) ) {
		foreach ( $selected_course_array as $id ) {
			if ( in_array( $id, $related_course_ids, true ) ) {
				array_push( $selected_course_ids, $id );
			}
		}
	}
	?>

	<!-- Display selectbox in metabox -->
	<select class="ldfbt-learndash-select2" name="ldfbt-ld-frequent-course[]" multiple="multiple" style="width:100%">
		<option selected="selected" value="<?php echo esc_attr( $current_course_id ); ?>" disabled><?php echo esc_html( get_the_title( $current_course_id ) ); ?> (<?php echo esc_html( $current_course_id ); ?>)</option>
		<?php
		foreach ( $related_course_ids as $id ) {
			if ( in_array( $id, $selected_course_array, true ) ) {
				?>
				<option selected="selected" value="<?php echo esc_attr( $id ); ?> "><?php echo esc_html( get_the_title( $id ) ); ?> (<?php echo esc_html( $id ); ?>)</option>
			<?php } else { ?>
				<option value="<?php echo esc_attr( $id ); ?>"><?php echo esc_html( get_the_title( $id ) ); ?> (<?php echo esc_html( $id ); ?>) </option>
				<?php
			}
		}
		?>
	</select>
	<?php
}

/**
 * Add frequent course metabox.
 */
function ldfbt_meta_frequent_boxes_callback() {
	add_meta_box( 'ldfbt-frequent-course', __( 'Frequently Bought Together Widget', 'ldfbt-frequently-bought-products' ), 'ldfbt_frequent_course_metabox_callback', array( 'sfwd-courses' ), 'advanced', 'low' );
}
add_action( 'add_meta_boxes', 'ldfbt_meta_frequent_boxes_callback' );

/**
 * Save value in frequent-course meta field that is selected from the metabox.
 */
function ldfbt_update_metafield() {

	// Take the current page post editor type skip updating to metafield when updating with elementor.
	if ( isset( $_REQUEST['action'] ) ) {

		if ( 'elementor_ajax' !== $_REQUEST['action'] ) {

			// stores all selected metabox course id in 'ldfbt-frequent-course' post meta.
			if ( isset( $_POST['ldfbt-ld-frequent-course'] ) ) {
				update_post_meta( get_the_ID(), 'ldfbt-frequent-course', map_deep( $_POST['ldfbt-ld-frequent-course'], 'intval' ) );
			} else {
				update_post_meta( get_the_ID(), 'ldfbt-frequent-course', null );
			}
		}
	}
}
add_action( 'save_post_sfwd-courses', 'ldfbt_update_metafield' );
