<?php
/**
 * Plugin Name: Frequently Bought Together For LearnDash
 * Description: Frequently Bought Together for LearnDash is a plugin that allows you to display a section that shows courses most usually bought together with the course listing watched by customers.
 * Plugin URI:  https://www.saffiretech.com/frequently-bought-together-for-learndash
 * Author URI:  https://www.saffiretech.com
 * Author:      SaffireTech
 * Text Domain: ldfbt-frequently-bought-products
 * Domain Path: /languages
 * Stable Tag : 1.0.1
 * Requires at least: 5.3
 * Tested up to: 6.1.1
 * Requires PHP: 7.2
 * LD Requires at least: 3.6.0.3
 * LD tested up to: 4.4.1.2
 * License:    GPLv3
 * License URI: https://www.gnu.org/licenses/gpl-3.0.html
 * Version:     1.0.1
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit(); // Exit if accessed directly.
}

/**
 * Check the installation of pro version.
 *
 * @return bool
 */
function ldfbt_check_pro_version() {
	require_once ABSPATH . 'wp-admin/includes/plugin.php';
	if ( is_plugin_active( 'frequently-bought-together-learndash-pro/frequently-bought-together-learndash-pro.php' ) ) {
		return true;
	} else {
		return false;
	}
}

/**
 * Display notice if pro plugin found.
 */
function ldfbt_free_plugin_install() {
	require_once ABSPATH . 'wp-admin/includes/plugin.php';

	// if pro plugin found deactivate free plugin.
	if ( ldfbt_check_pro_version() ) {

		deactivate_plugins( plugin_basename( __FILE__ ), true ); // deactivate free plugin if pro found.
		if ( defined( 'LDFBT_PRO_PLUGIN' ) ) {
			if ( isset( $_GET['activate'] ) ) {
				unset( $_GET['activate'] );
			}
			add_action( 'admin_notices', 'ldfbt_install_free_admin_notice' );
		}
	}
}
add_action( 'plugins_loaded', 'ldfbt_free_plugin_install' );

/**
 * Add message if pro version is installed.
 */
function ldfbt_install_free_admin_notice() {    ?>
	<div class="notice notice-error is-dismissible">
		<p><?php esc_html_e( 'Free version deactivated Pro version Installed', 'ldfbt-frequently-bought-products' ); ?></p>
	</div>
	<?php
}

/**
 * Loads FBT settings files.
 */
function ldfbt_free_load_settings() {
	if ( ! ldfbt_check_pro_version() ) {
		require dirname( __FILE__ ) . '/include/ldfbt-class-setting-page.php'; // gets course ids from product id.
		require dirname( __FILE__ ) . '/include/ldfbt-class-setting-fields.php'; // gets course ids from product id.
	}
}
add_action( 'plugins_loaded', 'ldfbt_free_load_settings' );

/**
 * Loads all plugin files.
 */
function ldfbt_free_load_required_files() {
	if ( ! ldfbt_check_pro_version() ) {
		require_once dirname( __FILE__ ) . '/include/ldfbt-setting-functions.php'; // code for setting function.
		require_once dirname( __FILE__ ) . '/include/ldfbt-widget-metabox.php'; // metabox page.
		require_once dirname( __FILE__ ) . '/include/ldfbt-process-add-cart.php'; // code for add to cart.
		require_once dirname( __FILE__ ) . '/include/ldfbt-frequently-bought-widget.php'; // code for frequent product widget.
		require_once dirname( __FILE__ ) . '/include/ldfbt-process-courses.php'; // gets courses id.
	}
}
add_action( 'init', 'ldfbt_free_load_required_files' );

/**
 * Loads required js & css file.
 */
function ldfbt_free_load_required_css_js_files() {
	if ( ! ldfbt_check_pro_version() ) {
		wp_enqueue_script( 'jquery' );
		load_plugin_textdomain( 'ldfbt-frequently-bought-products', false, basename( dirname( __FILE__ ) ) . '/languages/' );
		wp_enqueue_style( 'ldfbt-course-css', plugins_url( 'assets/css/ldfbt-courses-style.css', __FILE__ ), array(), '1.0.0' );
		wp_enqueue_style( 'ldfbt-select2-css', plugins_url( 'assets/css/select2.min.css', __FILE__ ), array(), '1.1.0' );
		wp_enqueue_script( 'ldfbt-free-course-js', plugins_url( 'assets/js/ldfbt-frequent-courses.js', __FILE__ ), array( 'jquery' ), '1.0.0', false );
		wp_enqueue_script( 'ldfbt-select2-js', plugins_url( 'assets/js/select2.min.js', __FILE__ ), array( 'jquery' ), '1.1.0', false );
		wp_enqueue_style( 'ldfbt-icon-css', esc_url( 'https://cdnjs.cloudflare.com/ajax/libs/font-awesome/4.7.0/css/font-awesome.min.css' ), array(), '4.7.0' );
		wp_localize_script(
			'ldfbt-free-course-js',
			'ldfbt_data',
			array(
				'ajaxurl'                  => admin_url( 'admin-ajax.php' ),
				'nonce'                    => wp_create_nonce( 'ldfbt-frequently-bought-products' ),
				'ldfbt_plugin_wc_install'  => ldfbt_is_woocom_active() + ldfbt_is_woocom_ld_active(),
				'ldfbt_plugin_edd_install' => ldfbt_is_edd_active() + ldfbt_is_edd_ld_active(),
			)
		);
	}
}
add_action( 'init', 'ldfbt_free_load_required_css_js_files' );

/**
 * Settings link in plugin page.
 *
 * @param array $links links Plugin links on plugins.php.
 * @return array
 */
function ldfbt_free_action_links_callback( $links ) {
	if ( ! ldfbt_check_pro_version() ) {
		$settinglinks = array(
			'<a href="' . admin_url( 'admin.php?page=ldfbt_upsell_settings' ) . '">' . __( 'setting', 'ldfbt-frequently-bought-products' ) . '</a>',
		);
		return array_merge( $settinglinks, $links );
	} else {
		return $links;
	}
}
add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'ldfbt_free_action_links_callback', 10, 1 );
